"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PolygonModule = void 0;
const core_1 = require("@credo-ts/core");
const PolygonApi_1 = require("./PolygonApi");
const PolygonModuleConfig_1 = require("./PolygonModuleConfig");
const ledger_1 = require("./ledger");
const signature_suites_1 = require("./signature-suites");
class PolygonModule {
    constructor(options) {
        this.api = PolygonApi_1.PolygonApi;
        this.config = new PolygonModuleConfig_1.PolygonModuleConfig(options);
    }
    register(dependencyManager) {
        // Warn about experimental module
        dependencyManager.registerInstance(PolygonModuleConfig_1.PolygonModuleConfig, this.config);
        // Services
        dependencyManager.registerSingleton(ledger_1.PolygonLedgerService);
        // Api
        dependencyManager.registerContextScoped(PolygonApi_1.PolygonApi);
        // Signature suites.
        dependencyManager.registerInstance(core_1.SignatureSuiteToken, {
            suiteClass: signature_suites_1.EcdsaSecp256k1Signature2019,
            proofType: 'EcdsaSecp256k1Signature2019',
            verificationMethodTypes: [core_1.VERIFICATION_METHOD_TYPE_ECDSA_SECP256K1_VERIFICATION_KEY_2019],
            keyTypes: [core_1.KeyType.K256],
        });
    }
}
exports.PolygonModule = PolygonModule;
//# sourceMappingURL=PolygonModule.js.map